import React from 'react';
import { Router, Route, Switch } from 'dva/router';
import zhCN from 'antd/es/locale/zh_CN';
import styles from './style.module.less';
import { ConfigProvider, Layout } from 'antd';
import dva, { connect } from 'dva';
import { createBrowserHistory as createHistory } from 'history';
import Component from 'Component';
import propsConfig from 'Component/src/props.config.js';
import componentPackage from 'Component/package.json';
import Theme from '@icode-run/theme';
import themePropsConfig from '@icode-run/theme/src/props.config.js';
import themePackage from '@icode-run/theme/package.json';
const { Header } = Layout;

import importRemote, {setRemoteConfig} from 'import-remote-module';
setRemoteConfig({
  web: 'https://www.icoderun.com/web/remoteEntry.js?75aca5b0f70d34588936'
})
const MyDesigner = importRemote('web/designer');


const propsConfigs = {
  [componentPackage.name]: {
    type: "element",
    component: 'Component',
    name: propsConfig.name,
    config: {
      packageInfo: {
        name: propsConfig.name,
        packageName: componentPackage.name,
        type: "element",
        component: 'Component',
        remoteAppName: '',
        remoteEntryPath: '',
      },
      ...propsConfig
    }
  },
  [themePackage.name]: {
    type: "element",
    component: 'Theme',
    name: themePropsConfig.name,
    config: {
      packageInfo: {
        name: themePropsConfig.name,
        packageName: themePackage.name,
        type: "element",
        component: 'Theme',
        remoteAppName: '',
        remoteEntryPath: '',
      },
      ...themePropsConfig
    }
  },
}
 
const app = dva({
  history: createHistory(),
});
 
app.router(history => {
//  const location = history.history.location;
  return (
    <Router history={history.history}>
        <Switch>
          <Route
            key={'/sdff'}
            path={'/'}
            render={() => {
              return (
                <ConfigProvider locale={zhCN}>
                  <Header className={styles.header} theme="dark">
                    <a onClick={() => {
                        history.push('/');
                      }}>
                    <div className={styles.logo}></div>
                    </a>
                  </Header>
                  {<MyDesigner
                    connect={connect}
                    app={app}
                    importComponents={{
                      [componentPackage.name]: Component,
                      [themePackage.name]: Theme
                    }}
                    componentDefaultConfigs={propsConfigs}
                    componentList={[]}
                    //  dataModels={null}
                    singleComponentName={componentPackage.name}
                    //  componentConfig={null}
                    globalState={{
                      backgroundColor: "rgba(0,10,61,1)",
                      borderColor: "rgba(51,72,127,1)",
                      chartColors: ["#72e3f2", "#72a3f2", "#d072f2", "#f272d2", "#72f2bf", "#f29072", "#a3f272", "#e3f272", "#9072f2", "#72f27f", "#f27292", "#f2d072"],
                      errorColor: "#ff4d4f",
                      primaryColor: "rgba(19,208,249,1)",
                      successColor: "#52c41a",
                      textColor: "rgba(156,192,245,1)",
                      themeMode: "dark",
                      tooltipBackgroundColor: "#fff",
                      tooltipTextColor: "rgba(0, 0, 0, 0.85)",
                      warningColor: "#faad14",
                    }}

                    key={'designer}'}
                    designer={'designer'} /> }
                </ConfigProvider>
              );
            }}
          />
        </Switch>
    </Router>
  );
});
 
// 5. Start
app.start('#component-layout-root');
 